/*Configurations of BLE for pairing */

#ifndef BLE_CONFIG_H
#define BLE_CONFIG_H

#include <zephyr/kernel.h>
#include <zephyr/bluetooth/bluetooth.h>
#include <zephyr/bluetooth/gap.h>
#include <zephyr/bluetooth/conn.h>
#include <zephyr/bluetooth/uuid.h>
#include <zephyr/bluetooth/gatt.h>
#include <zephyr/bluetooth/addr.h>
#include <zephyr/bluetooth/hci.h>
#include <zephyr/logging/log.h>
#include <zephyr/logging/log_core.h>
#include <zephyr/bluetooth/testing.h>
#include <zephyr/bluetooth/att.h>
#include <zephyr/bluetooth/services/dis.h>

#define DEVICE_NAME CONFIG_BT_DEVICE_NAME
#define DEVICE_NAME_LEN (sizeof(DEVICE_NAME)-1)
int err;
/* Custom Service Variables */
#define BT_UUID_CUSTOM_SERVICE_VAL  BT_UUID_128_ENCODE(0x821675c3, 0x4046, 0x45f9, 0xb8df, 0xcdc9da1c71a7)

#define CUSTOM_EMG_UUID BT_UUID_128_ENCODE(0x30645c07,0x5a3c,0x4f2d,0xbee5,0x7eafcbf0c790)
#define CUSTOM_BATTERY_UUID BT_UUID_128_ENCODE(0xd7b5a586,0x6191,0x4c0f,0x93e0,0xc2fa666d5ca3)

#define BT_UUID_EMG_DEV BT_UUID_DECLARE_128(BT_UUID_CUSTOM_SERVICE_VAL)
#define BT_UUID_BAT     BT_UUID_DECLARE_128(CUSTOM_BATTERY_UUID)
#define BT_UUID_EMG     BT_UUID_DECLARE_128(CUSTOM_EMG_UUID)

extern char *battery_value[10];
extern char *emg_value[10];

extern ssize_t read_battery(struct bt_conn *conn, const struct bt_gatt_attr *attr,void *buf,uint16_t len,uint16_t offset);
extern ssize_t read_emg(struct bt_conn *conn,const struct bt_gatt_attr *attr,void *buf,uint16_t len,uint16_t offset);


/**
 *  @brief  Define and register device service.
 *  @param _name Service name = custom_service.
 */
BT_GATT_SERVICE_DEFINE(custom_svc,
BT_GATT_PRIMARY_SERVICE(BT_UUID_EMG_DEV),

BT_GATT_CHARACTERISTIC(BT_UUID_BAT,
                       BT_GATT_CHRC_READ|BT_GATT_CHRC_BROADCAST|BT_GATT_CHRC_NOTIFY,
                       BT_GATT_PERM_READ,
                       read_battery,NULL,&battery_value),         
                       
BT_GATT_CHARACTERISTIC(BT_UUID_EMG,
                  BT_GATT_CHRC_READ|BT_GATT_CHRC_NOTIFY,
                  BT_GATT_PERM_READ,
                  read_emg,NULL,&emg_value),
);

extern const struct  bt_data ad[];
extern const struct bt_data sd[];
extern struct bt_le_adv_param *adv_pram;
void on_connected(struct bt_conn *conn,uint8_t err);
void on_disconnected(struct bt_conn *conn, uint8_t reason);
void bt_ready(void);
extern struct bt_conn_cb connection_callbacks;

#endif